# Table of Contents

- [configuring-kpis](<./configuring-kpis.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Configuring KPIs](<./Configuring-KPIs.md>)
  - [Overview](<./Configuring-KPIs/Overview.md>)
  - [Prerequisites](<./Configuring-KPIs/Prerequisites.md>)
  - [Creating a Custom KPI](<./Configuring-KPIs/Creating-a-Custom-KPI.md>)
  - [Calculation Methods](<./Configuring-KPIs/Calculation-Methods.md>)
  - [Aggregation Options](<./Configuring-KPIs/Aggregation-Options.md>)
  - [Inventory Filters](<./Configuring-KPIs/Inventory-Filters.md>)
  - [Examples](<./Configuring-KPIs/Examples.md>)
  - [Was this page helpful?](<./Configuring-KPIs/Was-this-page-helpful.md>)
